@@ -3,9 +3,6 @@ import os
 AZURE_CLIENT_ID = os.environ.get('AZURE_CLIENT_ID', '')
 AZURE_CLIENT_SECRET = os.environ.get('AZURE_CLIENT_SECRET', '')
 
-INSIGHT_URL = os.environ.get('INSIGHT_URL', 'https://unibiapitest.azure-api.net/biapi/v1/')
-INSIGHT_SUB_KEY = os.environ.get('INSIGHT_SUB_KEY', 'insight_sub_key')
-
 GRAPH_CLIENT_ID = os.environ.get('GRAPH_CLIENT_ID', AZURE_CLIENT_ID)
 GRAPH_CLIENT_SECRET = os.environ.get('GRAPH_CLIENT_SECRET', AZURE_CLIENT_SECRET)
 
